[SCM] WebKit Debian packaging branch, debian/experimental, updated. upstream/1.3.3-9427-gc2be6fc

aroben at apple.com aroben at apple.com
Wed Dec 22 11:36:25 UTC 2010


The following commit has been merged in the debian/experimental branch:
commit 8fcda744ab08a31b1105ba9cbe14e3e7cd3645be
Author: aroben at apple.com <aroben at apple.com@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Fri Jul 30 18:18:04 2010 +0000

    Roll our r64361 and r64363
    
    We can't make these changes until QuartzCore.lib is included in
    WebKitSupportLibrary.
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@64364 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog b/WebCore/ChangeLog
index d70172d..d9b4187 100644
--- a/WebCore/ChangeLog
+++ b/WebCore/ChangeLog
@@ -1,5 +1,12 @@
 2010-07-30  Adam Roben  <aroben at apple.com>
 
+        Roll our r64361 and r64363
+
+        We can't make these changes until QuartzCore.lib is included in
+        WebKitSupportLibrary.
+
+2010-07-30  Adam Roben  <aroben at apple.com>
+
         Remove uses of CACFContextRef and CARender* from WebCore
 
         These types are now wrapped in a WKCACFContext type exported by
diff --git a/WebCore/platform/graphics/win/WKCACFContextFlusher.cpp b/WebCore/platform/graphics/win/WKCACFContextFlusher.cpp
index d75c854..1685a30 100644
--- a/WebCore/platform/graphics/win/WKCACFContextFlusher.cpp
+++ b/WebCore/platform/graphics/win/WKCACFContextFlusher.cpp
@@ -29,8 +29,8 @@
 
 #include "WKCACFContextFlusher.h"
 
-#include <WebKitSystemInterface/WebKitSystemInterface.h>
 #include <wtf/StdLibExtras.h>
+#include <QuartzCore/CACFContext.h>
 
 namespace WebCore {
 
@@ -48,18 +48,24 @@ WKCACFContextFlusher::~WKCACFContextFlusher()
 {
 }
 
-void WKCACFContextFlusher::addContext(WKCACFContext* context)
+void WKCACFContextFlusher::addContext(CACFContextRef context)
 {
     ASSERT(context);
 
-    m_contexts.add(context);
+    if (m_contexts.add(context).second)
+        CFRetain(context);
 }
 
-void WKCACFContextFlusher::removeContext(WKCACFContext* context)
+void WKCACFContextFlusher::removeContext(CACFContextRef context)
 {
     ASSERT(context);
 
-    m_contexts.remove(context);
+    ContextSet::iterator found = m_contexts.find(context);
+    if (found == m_contexts.end())
+        return;
+
+    CFRelease(*found);
+    m_contexts.remove(found);
 }
 
 void WKCACFContextFlusher::flushAllContexts()
@@ -70,8 +76,11 @@ void WKCACFContextFlusher::flushAllContexts()
     contextsToFlush.swap(m_contexts);
 
     ContextSet::const_iterator end = contextsToFlush.end();
-    for (ContextSet::const_iterator it = contextsToFlush.begin(); it != end; ++it)
-        wkCACFContextFlush(*it);
+    for (ContextSet::const_iterator it = contextsToFlush.begin(); it != end; ++it) {
+        CACFContextRef context = *it;
+        CACFContextFlush(context);
+        CFRelease(context);
+    }
 }
 
 }
diff --git a/WebCore/platform/graphics/win/WKCACFContextFlusher.h b/WebCore/platform/graphics/win/WKCACFContextFlusher.h
index 17ec41d..9ce76aa 100644
--- a/WebCore/platform/graphics/win/WKCACFContextFlusher.h
+++ b/WebCore/platform/graphics/win/WKCACFContextFlusher.h
@@ -32,7 +32,7 @@
 
 #include <wtf/HashSet.h>
 
-struct WKCACFContext;
+typedef struct _CACFContext* CACFContextRef;
 
 namespace WebCore {
 
@@ -40,8 +40,8 @@ class WKCACFContextFlusher : public Noncopyable {
 public:
     static WKCACFContextFlusher& shared();
 
-    void addContext(WKCACFContext*);
-    void removeContext(WKCACFContext*);
+    void addContext(CACFContextRef);
+    void removeContext(CACFContextRef);
 
     void flushAllContexts();
 
@@ -49,7 +49,7 @@ private:
     WKCACFContextFlusher();
     ~WKCACFContextFlusher();
 
-    typedef HashSet<WKCACFContext*> ContextSet;
+    typedef HashSet<CACFContextRef> ContextSet;
     ContextSet m_contexts;
 };
 
diff --git a/WebCore/platform/graphics/win/WKCACFLayer.cpp b/WebCore/platform/graphics/win/WKCACFLayer.cpp
index 416c497..b5f3427 100644
--- a/WebCore/platform/graphics/win/WKCACFLayer.cpp
+++ b/WebCore/platform/graphics/win/WKCACFLayer.cpp
@@ -30,10 +30,15 @@
 #include "WKCACFLayer.h"
 
 #include "WKCACFLayerRenderer.h"
-#include <WebKitSystemInterface/WebKitSystemInterface.h>
+#include <wtf/text/CString.h>
+
 #include <stdio.h>
+#include <QuartzCore/CACFContext.h>
+#include <QuartzCore/CARender.h>
+
+#ifndef NDEBUG
 #include <wtf/CurrentTime.h>
-#include <wtf/text/CString.h>
+#endif
 
 namespace WebCore {
 
@@ -160,9 +165,9 @@ WKCACFLayer::~WKCACFLayer()
     CACFLayerSetDisplayCallback(layer(), 0);
 }
 
-void WKCACFLayer::becomeRootLayerForContext(WKCACFContext* context)
+void WKCACFLayer::becomeRootLayerForContext(CACFContextRef context)
 {
-    wkCACFContextSetLayer(context, layer());
+    CACFContextSetLayer(context, layer());
     setNeedsCommit();
 }
 
diff --git a/WebCore/platform/graphics/win/WKCACFLayer.h b/WebCore/platform/graphics/win/WKCACFLayer.h
index ee19247..ed39297 100644
--- a/WebCore/platform/graphics/win/WKCACFLayer.h
+++ b/WebCore/platform/graphics/win/WKCACFLayer.h
@@ -42,8 +42,6 @@
 #include "PlatformString.h"
 #include "TransformationMatrix.h"
 
-struct WKCACFContext;
-
 namespace WebCore {
 
 class WKCACFLayer;
@@ -82,7 +80,7 @@ public:
     }
 
     // Makes this layer the root when the passed context is rendered
-    void becomeRootLayerForContext(WKCACFContext*);
+    void becomeRootLayerForContext(CACFContextRef);
 
     static RetainPtr<CFTypeRef> cfValue(float value) { return RetainPtr<CFTypeRef>(AdoptCF, CFNumberCreate(0, kCFNumberFloat32Type, &value)); }
     static RetainPtr<CFTypeRef> cfValue(const TransformationMatrix& value)
diff --git a/WebCore/platform/graphics/win/WKCACFLayerRenderer.h b/WebCore/platform/graphics/win/WKCACFLayerRenderer.h
index fa890f5..2647c5f 100644
--- a/WebCore/platform/graphics/win/WKCACFLayerRenderer.h
+++ b/WebCore/platform/graphics/win/WKCACFLayerRenderer.h
@@ -41,7 +41,9 @@
 #include <CoreGraphics/CGGeometry.h>
 
 interface IDirect3DDevice9;
-struct WKCACFContext;
+typedef struct _CACFContext* CACFContextRef;
+typedef struct _CARenderContext CARenderContext;
+typedef struct _CARenderOGLContext CARenderOGLContext;
 
 namespace WebCore {
 
@@ -62,7 +64,7 @@ public:
     ~WKCACFLayerRenderer();
 
     static bool acceleratedCompositingAvailable();
-    static void didFlushContext(WKCACFContext*);
+    static void didFlushContext(CACFContextRef);
 
     void setScrollFrame(const IntPoint&, const IntSize&);
     void setRootContents(CGImageRef);
@@ -106,7 +108,9 @@ private:
     RefPtr<WKCACFLayer> m_scrollLayer;
     RefPtr<WKCACFLayer> m_rootChildLayer;
     RefPtr<WKCACFLayer> m_clipLayer;
-    WKCACFContext* m_context;
+    RetainPtr<CACFContextRef> m_context;
+    CARenderContext* m_renderContext;
+    CARenderOGLContext* m_renderer;
     HWND m_hostWindow;
     Timer<WKCACFLayerRenderer> m_renderTimer;
     IntPoint m_scrollPosition;
diff --git a/WebKit2/ChangeLog b/WebKit2/ChangeLog
index 97a2a7d..409ecb4 100644
--- a/WebKit2/ChangeLog
+++ b/WebKit2/ChangeLog
@@ -1,5 +1,12 @@
 2010-07-30  Adam Roben  <aroben at apple.com>
 
+        Roll our r64361 and r64363
+
+        We can't make these changes until QuartzCore.lib is included in
+        WebKitSupportLibrary.
+
+2010-07-30  Adam Roben  <aroben at apple.com>
+
         Windows build fix
 
         * win/WebKit2Apple.vsprops: Always link against QuartzCore, since
diff --git a/WebKit2/win/WebKit2Apple.vsprops b/WebKit2/win/WebKit2Apple.vsprops
index 1d4cea4..d6a24b2 100644
--- a/WebKit2/win/WebKit2Apple.vsprops
+++ b/WebKit2/win/WebKit2Apple.vsprops
@@ -6,7 +6,7 @@
 	>
 	<Tool
 		Name="VCLinkerTool"
-		AdditionalDependencies="CFNetwork$(LibraryConfigSuffix).lib CoreFoundation$(LibraryConfigSuffix).lib CoreGraphics$(LibraryConfigSuffix).lib QTMovieWin$(WebKitConfigSuffix).lib WebKitSystemInterface$(WebKitConfigSuffix).lib QuartzCore$(WebKitConfigSuffix).lib"
+		AdditionalDependencies="CFNetwork$(LibraryConfigSuffix).lib CoreFoundation$(LibraryConfigSuffix).lib CoreGraphics$(LibraryConfigSuffix).lib QTMovieWin$(WebKitConfigSuffix).lib WebKitSystemInterface$(WebKitConfigSuffix).lib"
 		ModuleDefinitionFile="WebKit2.def"
 		DelayLoadDLLs="QTMovieWin$(WebKitConfigSuffix).dll"
 	/>
diff --git a/WebKitLibraries/ChangeLog b/WebKitLibraries/ChangeLog
index 4028826..5f626fd 100644
--- a/WebKitLibraries/ChangeLog
+++ b/WebKitLibraries/ChangeLog
@@ -1,5 +1,12 @@
 2010-07-30  Adam Roben  <aroben at apple.com>
 
+        Roll our r64361 and r64363
+
+        We can't make these changes until QuartzCore.lib is included in
+        WebKitSupportLibrary.
+
+2010-07-30  Adam Roben  <aroben at apple.com>
+
         Add WKCACFContext and related functions
 
         Also added some functions used by WKCAImageQueue.
diff --git a/WebKitLibraries/win/include/WebKitSystemInterface/WebKitSystemInterface.h b/WebKitLibraries/win/include/WebKitSystemInterface/WebKitSystemInterface.h
index ae840ae..445b292 100644
--- a/WebKitLibraries/win/include/WebKitSystemInterface/WebKitSystemInterface.h
+++ b/WebKitLibraries/win/include/WebKitSystemInterface/WebKitSystemInterface.h
@@ -28,27 +28,21 @@
 
 struct CGAffineTransform;
 struct CGPoint;
-struct CGRect;
 struct CGSize;
-struct IDirect3DDevice9;
-struct WKCACFContext;
-struct WKCACFUpdateRectEnumerator;
 
-typedef struct _CACFLayer* CACFLayerRef;
 typedef const struct __CFData* CFDataRef;
 typedef const struct __CFString* CFStringRef;
-typedef double CFTimeInterval;
 typedef struct CGColor* CGColorRef;
 typedef struct CGContext* CGContextRef;
 typedef unsigned short CGFontIndex;
 typedef struct CGFont* CGFontRef;
 typedef CGFontIndex CGGlyph;
 typedef wchar_t UChar;
-typedef struct _CFURLCredential* CFURLCredentialRef;
 typedef struct _CFURLResponse* CFURLResponseRef;
 typedef struct OpaqueCFHTTPCookieStorage*  CFHTTPCookieStorageRef;
 typedef struct _CFURLRequest* CFMutableURLRequestRef;
 typedef const struct _CFURLRequest* CFURLRequestRef;
+typedef struct _CFURLCredential* CFURLCredentialRef;
 typedef struct __CFHTTPMessage* CFHTTPMessageRef;
 typedef const struct __CFNumber* CFNumberRef;
 typedef struct __CFReadStream* CFReadStreamRef;
@@ -56,12 +50,6 @@ typedef const struct __CFURL* CFURLRef;
 typedef struct _CFURLProtectionSpace* CFURLProtectionSpaceRef;
 typedef struct tagLOGFONTW LOGFONTW;
 typedef LOGFONTW LOGFONT;
-typedef struct _CACFLayer *CACFLayerRef;
-typedef struct __CVBuffer *CVBufferRef;
-typedef CVBufferRef CVImageBufferRef;
-typedef CVImageBufferRef CVPixelBufferRef;
-typedef struct _CAImageQueue *CAImageQueueRef;
-typedef unsigned long CFTypeID;
 
 void wkSetFontSmoothingLevel(int type);
 int wkGetFontSmoothingLevel();
@@ -101,57 +89,4 @@ CFURLCredentialRef wkCopyCredentialFromCFPersistentStorage(CFURLProtectionSpaceR
 
 CFStringRef wkCFNetworkErrorGetLocalizedDescription(CFIndex errorCode);
 
-
-enum wkCAImageQueueFlags {
-    kWKCAImageQueueAsync = 1U << 0,
-    kWKCAImageQueueFill = 1U << 1,
-    kWKCAImageQueueProtected = 1U << 2,
-    kWKCAImageQueueUseCleanAperture = 1U << 3,
-    kWKCAImageQueueUseAspectRatio = 1U << 4,
-    kWKCAImageQueueLowQualityColor = 1U << 5,
-};
-
-enum wkWKCAImageQueueImageType {
-    kWKCAImageQueueNil = 1,
-    kWKCAImageQueueSurface,
-    kWKCAImageQueueBuffer,
-    kWKCAImageQueueIOSurface,
-};
-
-enum wkWKCAImageQueueImageFlags {
-    kWKCAImageQueueOpaque = 1U << 0,
-    kWKCAImageQueueFlush = 1U << 1,
-    kWKCAImageQueueWillFlush = 1U << 2,
-    kWKCAImageQueueFlipped = 1U << 3,
-    kWKCAImageQueueWaitGPU = 1U << 4,
-};
-
-typedef void (*wkCAImageQueueReleaseCallback)(unsigned int type, uint64_t id, void *info);
-CAImageQueueRef wkCAImageQueueCreate(uint32_t width, uint32_t height, uint32_t capacity);
-void wkCAImageQueueInvalidate(CAImageQueueRef iq);
-size_t wkCAImageQueueCollect(CAImageQueueRef iq);
-bool wkCAImageQueueInsertImage(CAImageQueueRef iq, CFTimeInterval t, unsigned int type, uint64_t id, uint32_t flags, wkCAImageQueueReleaseCallback release, void *info);
-uint64_t wkCAImageQueueRegisterPixelBuffer(CAImageQueueRef iq, void *data, size_t data_size, size_t rowbytes, size_t width, size_t height, OSType pixel_format, CFDictionaryRef attachments, uint32_t flags);
-void wkCAImageQueueSetFlags(CAImageQueueRef iq, uint32_t mask, uint32_t flags);
-uint32_t wkCAImageQueueGetFlags(CAImageQueueRef iq);
-CFTypeID wkCAImageQueueGetTypeID(void);
-
-WKCACFContext* wkCACFContextCreate();
-void wkCACFContextDestroy(WKCACFContext*);
-
-void wkCACFContextSetLayer(WKCACFContext*, CACFLayerRef);
-void wkCACFContextFlush(WKCACFContext*);
-
-void wkCACFContextInitializeD3DDevice(WKCACFContext*, IDirect3DDevice9*);
-void wkCACFContextReleaseD3DResources(WKCACFContext*);
-
-bool wkCACFContextBeginUpdate(WKCACFContext*, void* buffer, size_t bufferSize, CFTimeInterval time, const CGRect& bounds, const CGRect dirtyRects[], size_t dirtyRectCount);
-void wkCACFContextRenderUpdate(WKCACFContext*);
-void wkCACFContextFinishUpdate(WKCACFContext*);
-void wkCACFContextAddUpdateRect(WKCACFContext*, const CGRect&);
-
-WKCACFUpdateRectEnumerator* wkCACFContextCopyUpdateRectEnumerator(WKCACFContext*);
-const CGRect* wkCACFUpdateRectEnumeratorNextRect(WKCACFUpdateRectEnumerator*);
-void wkCACFUpdateRectEnumeratorRelease(WKCACFUpdateRectEnumerator*);
-
 #endif // WebKitSystemInterface_h
diff --git a/WebCore/platform/graphics/win/WKCACFLayerRenderer.cpp b/WebCore/platform/graphics/win/WKCACFLayerRenderer.cpp
index 623d31a..2a355c2 100644
--- a/WebCore/platform/graphics/win/WKCACFLayerRenderer.cpp
+++ b/WebCore/platform/graphics/win/WKCACFLayerRenderer.cpp
@@ -36,7 +36,9 @@
 #include "WKCACFContextFlusher.h"
 #include "WKCACFLayer.h"
 #include "WebCoreInstanceHandle.h"
-#include <WebKitSystemInterface/WebKitSystemInterface.h>
+#include <CoreGraphics/CGSRegion.h>
+#include <QuartzCore/CACFContext.h>
+#include <QuartzCore/CARenderOGL.h>
 #include <wtf/HashMap.h>
 #include <wtf/OwnArrayPtr.h>
 #include <wtf/OwnPtr.h>
@@ -106,7 +108,7 @@ private:
     WKCACFLayerRenderer* m_renderer;
 };
 
-typedef HashMap<WKCACFContext*, WKCACFLayerRenderer*> ContextToWindowMap;
+typedef HashMap<CACFContextRef, WKCACFLayerRenderer*> ContextToWindowMap;
 
 static ContextToWindowMap& windowsForContexts()
 {
@@ -204,7 +206,7 @@ bool WKCACFLayerRenderer::acceleratedCompositingAvailable()
     return available;
 }
 
-void WKCACFLayerRenderer::didFlushContext(WKCACFContext* context)
+void WKCACFLayerRenderer::didFlushContext(CACFContextRef context)
 {
     WKCACFLayerRenderer* window = windowsForContexts().get(context);
     if (!window)
@@ -226,7 +228,9 @@ WKCACFLayerRenderer::WKCACFLayerRenderer(WKCACFLayerRendererClient* client)
     , m_rootLayer(WKCACFRootLayer::create(this))
     , m_scrollLayer(WKCACFLayer::create(WKCACFLayer::Layer))
     , m_clipLayer(WKCACFLayer::create(WKCACFLayer::Layer))
-    , m_context(wkCACFContextCreate())
+    , m_context(AdoptCF, CACFContextCreate(0))
+    , m_renderContext(static_cast<CARenderContext*>(CACFContextGetRenderContext(m_context.get())))
+    , m_renderer(0)
     , m_hostWindow(0)
     , m_renderTimer(this, &WKCACFLayerRenderer::renderTimerFired)
     , m_scrollPosition(0, 0)
@@ -234,7 +238,7 @@ WKCACFLayerRenderer::WKCACFLayerRenderer(WKCACFLayerRendererClient* client)
     , m_backingStoreDirty(false)
     , m_mustResetLostDeviceBeforeRendering(false)
 {
-    windowsForContexts().set(m_context, this);
+    windowsForContexts().set(m_context.get(), this);
 
     // Under the root layer, we have a clipping layer to clip the content,
     // that contains a scroll layer that we use for scrolling the content.
@@ -263,7 +267,7 @@ WKCACFLayerRenderer::WKCACFLayerRenderer(WKCACFLayerRendererClient* client)
 #endif
 
     if (m_context)
-        m_rootLayer->becomeRootLayerForContext(m_context);
+        m_rootLayer->becomeRootLayerForContext(m_context.get());
 
 #ifndef NDEBUG
     char* printTreeFlag = getenv("CA_PRINT_TREE");
@@ -274,7 +278,6 @@ WKCACFLayerRenderer::WKCACFLayerRenderer(WKCACFLayerRendererClient* client)
 WKCACFLayerRenderer::~WKCACFLayerRenderer()
 {
     destroyRenderer();
-    wkCACFContextDestroy(m_context);
 }
 
 WKCACFLayer* WKCACFLayerRenderer::rootLayer() const
@@ -332,7 +335,7 @@ void WKCACFLayerRenderer::setRootChildLayer(WKCACFLayer* layer)
    
 void WKCACFLayerRenderer::layerTreeDidChange()
 {
-    WKCACFContextFlusher::shared().addContext(m_context);
+    WKCACFContextFlusher::shared().addContext(m_context.get());
     renderSoon();
 }
 
@@ -410,7 +413,7 @@ bool WKCACFLayerRenderer::createRenderer()
 
     m_d3dDevice->SetTransform(D3DTS_PROJECTION, &projection);
 
-    wkCACFContextInitializeD3DDevice(m_context, m_d3dDevice.get());
+    m_renderer = CARenderOGLNew(&kCARenderDX9Callbacks, m_d3dDevice.get(), 0);
 
     if (IsWindow(m_hostWindow))
         m_rootLayer->setBounds(bounds());
@@ -421,10 +424,14 @@ bool WKCACFLayerRenderer::createRenderer()
 void WKCACFLayerRenderer::destroyRenderer()
 {
     if (m_context) {
-        windowsForContexts().remove(m_context);
-        WKCACFContextFlusher::shared().removeContext(m_context);
+        CACFContextSetLayer(m_context.get(), 0);
+        windowsForContexts().remove(m_context.get());
+        WKCACFContextFlusher::shared().removeContext(m_context.get());
     }
 
+    if (m_renderer)
+        CARenderOGLDestroy(m_renderer);
+    m_renderer = 0;
     m_d3dDevice = 0;
     if (s_d3d)
         s_d3d->Release();
@@ -512,7 +519,7 @@ void WKCACFLayerRenderer::paint()
     render(dirtyRects);
 }
 
-void WKCACFLayerRenderer::render(const Vector<CGRect>& windowDirtyRects)
+void WKCACFLayerRenderer::render(const Vector<CGRect>& dirtyRects)
 {
     ASSERT(m_d3dDevice);
 
@@ -535,21 +542,31 @@ void WKCACFLayerRenderer::render(const Vector<CGRect>& windowDirtyRects)
     CFTimeInterval t = CACurrentMediaTime();
 
     // Give the renderer some space to use. This needs to be valid until the
-    // wkCACFContextFinishUpdate() call below.
+    // CARenderUpdateFinish() call below.
     char space[4096];
-    if (!wkCACFContextBeginUpdate(m_context, space, sizeof(space), t, bounds, windowDirtyRects.data(), windowDirtyRects.size()))
+    CARenderUpdate* u = CARenderUpdateBegin(space, sizeof(space), t, 0, 0, &bounds);
+    if (!u)
         return;
 
+    CARenderContextLock(m_renderContext);
+    CARenderUpdateAddContext(u, m_renderContext);
+    CARenderContextUnlock(m_renderContext);
+
+    for (size_t i = 0; i < dirtyRects.size(); ++i)
+        CARenderUpdateAddRect(u, &dirtyRects[i]);
+
     HRESULT err = S_OK;
     do {
-        // FIXME: don't need to clear dirty region if layer tree is opaque.
+        CGSRegionObj rgn = CARenderUpdateCopyRegion(u);
 
-        WKCACFUpdateRectEnumerator* e = wkCACFContextCopyUpdateRectEnumerator(m_context);
-        if (!e)
+        if (!rgn)
             break;
 
+        // FIXME: don't need to clear dirty region if layer tree is opaque.
+
         Vector<D3DRECT, 64> rects;
-        for (const CGRect* r = wkCACFUpdateRectEnumeratorNextRect(e); r; r = wkCACFUpdateRectEnumeratorNextRect(e)) {
+        CGSRegionEnumeratorObj e = CGSRegionEnumerator(rgn);
+        for (const CGRect* r = CGSNextRect(e); r; r = CGSNextRect(e)) {
             D3DRECT rect;
             rect.x1 = r->origin.x;
             rect.x2 = rect.x1 + r->size.width;
@@ -558,7 +575,8 @@ void WKCACFLayerRenderer::render(const Vector<CGRect>& windowDirtyRects)
 
             rects.append(rect);
         }
-        wkCACFUpdateRectEnumeratorRelease(e);
+        CGSReleaseRegionEnumerator(e);
+        CGSReleaseRegion(rgn);
 
         if (rects.isEmpty())
             break;
@@ -566,13 +584,13 @@ void WKCACFLayerRenderer::render(const Vector<CGRect>& windowDirtyRects)
         m_d3dDevice->Clear(rects.size(), rects.data(), D3DCLEAR_TARGET, 0, 1.0f, 0);
 
         m_d3dDevice->BeginScene();
-        wkCACFContextRenderUpdate(m_context);
+        CARenderOGLRender(m_renderer, u);
         m_d3dDevice->EndScene();
 
         err = m_d3dDevice->Present(0, 0, 0, 0);
 
         if (err == D3DERR_DEVICELOST) {
-            wkCACFContextAddUpdateRect(m_context, bounds);
+            CARenderUpdateAddRect(u, &bounds);
             if (!resetDevice(LostDevice)) {
                 // We can't reset the device right now. Try again soon.
                 renderSoon();
@@ -581,7 +599,7 @@ void WKCACFLayerRenderer::render(const Vector<CGRect>& windowDirtyRects)
         }
     } while (err == D3DERR_DEVICELOST);
 
-    wkCACFContextFinishUpdate(m_context);
+    CARenderUpdateFinish(u);
 
 #ifndef NDEBUG
     if (m_printTree)
@@ -623,7 +641,7 @@ void WKCACFLayerRenderer::initD3DGeometry()
 bool WKCACFLayerRenderer::resetDevice(ResetReason reason)
 {
     ASSERT(m_d3dDevice);
-    ASSERT(m_context);
+    ASSERT(m_renderContext);
 
     HRESULT hr = m_d3dDevice->TestCooperativeLevel();
 
@@ -642,10 +660,10 @@ bool WKCACFLayerRenderer::resetDevice(ResetReason reason)
 
     // We can reset the device.
 
     // We have to release the context's D3D resrouces whenever we reset the IDirect3DDevice9 in order to
     // destroy any D3DPOOL_DEFAULT resources that Core Animation has allocated (e.g., textures used
     // for mask layers). See <http://msdn.microsoft.com/en-us/library/bb174425(v=VS.85).aspx>.
-    wkCACFContextReleaseD3DResources(m_context);
+    CARenderOGLPurge(m_renderer);
 
     D3DPRESENT_PARAMETERS parameters = initialPresentationParameters();
     hr = m_d3dDevice->Reset(&parameters);
@@ -642,10 +660,10 @@ bool WKCACFLayerRenderer::resetDevice(ResetReason reason)
     // We can reset the device.
 
-    // We have to release the context's D3D resrouces whenever we reset the IDirect3DDevice9 in order to
+    // We have to purge the CARenderOGLContext whenever we reset the IDirect3DDevice9 in order to
     // destroy any D3DPOOL_DEFAULT resources that Core Animation has allocated (e.g., textures used
     // for mask layers). See <http://msdn.microsoft.com/en-us/library/bb174425(v=VS.85).aspx>.
diff --git a/WebKitLibraries/win/lib/WebKitSystemInterface.lib b/WebKitLibraries/win/lib/WebKitSystemInterface.lib
index d1eafbf..4fcc36b 100644
Binary files a/WebKitLibraries/win/lib/WebKitSystemInterface.lib and b/WebKitLibraries/win/lib/WebKitSystemInterface.lib differ
diff --git a/WebKitLibraries/win/lib/WebKitSystemInterface_debug.lib b/WebKitLibraries/win/lib/WebKitSystemInterface_debug.lib
index b98ced6..6d836db 100644
Binary files a/WebKitLibraries/win/lib/WebKitSystemInterface_debug.lib and b/WebKitLibraries/win/lib/WebKitSystemInterface_debug.lib differ

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list